[jbpm-commits] JBoss JBPM SVN: r1705 - jbpm3/branches/tdiesler/modules/jpdl/core/src/main/java/org/jbpm.

do-not-reply at jboss.org do-not-reply at jboss.org
Thu Jul 24 07:42:45 EDT 2008


Author: thomas.diesler at jboss.com
Date: 2008-07-24 07:42:45 -0400 (Thu, 24 Jul 2008)
New Revision: 1705

Modified:
   jbpm3/branches/tdiesler/modules/jpdl/core/src/main/java/org/jbpm/JbpmConfiguration.java
Log:
Merge -r1578:1580

Modified: jbpm3/branches/tdiesler/modules/jpdl/core/src/main/java/org/jbpm/JbpmConfiguration.java
===================================================================
--- jbpm3/branches/tdiesler/modules/jpdl/core/src/main/java/org/jbpm/JbpmConfiguration.java	2008-07-24 11:40:18 UTC (rev 1704)
+++ jbpm3/branches/tdiesler/modules/jpdl/core/src/main/java/org/jbpm/JbpmConfiguration.java	2008-07-24 11:42:45 UTC (rev 1705)
@@ -278,12 +278,13 @@
             log.info("using jbpm configuration resource '"+resource+"'");
             InputStream jbpmCfgXmlStream = ClassLoaderUtil.getStream(resource);
 
             // if a resource SHOULD BE used, but is not found in the classpath
             // throw exception (otherwise, the user wants to load own stuff
             // but is confused, if it is not found and not loaded, without
             // any notice)
-            if (jbpmCfgXmlStream==null)
-              throw new JbpmException("jbpm configuration resource '"+resource+"' is not available");
+            if (jbpmCfgXmlStream==null && !"jbpm.cfg.xml".equals(resource)) {
+              log.warn("jbpm configuration resource '"+resource+"' is not available");
+            }
 
             ObjectFactory objectFactory = parseObjectFactory(jbpmCfgXmlStream);
             instance = createJbpmConfiguration(objectFactory);
@@ -278,12 +278,13 @@
             InputStream jbpmCfgXmlStream = ClassLoaderUtil.getStream(resource);
 
-            // if a resource SHOULD BE used, but is not found in the classpath
-            // throw exception (otherwise, the user wants to load own stuff
-            // but is confused, if it is not found and not loaded, without
+            // if a custom resource is to be used, but is not found in the classpath
+            // log a warning (otherwise, users who want to load custom stuff
+            // will be confused if the resource is not found and not loaded, without
             // any notice)




More information about the jbpm-commits mailing list